@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2014  Hong Jen Yee (PCMan) <pcman.tw@gmail.com>
- * LXQt project: https://lxqt.org/
+ * LXQt project: https://lxqt-project.org/
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,7 +31,7 @@ class FontConfigFile: public QObject
 {
     Q_OBJECT
 public:
-    explicit FontConfigFile(QObject* parent = 0);
+    explicit FontConfigFile(QObject* parent = nullptr);
     virtual ~FontConfigFile();
 
     bool antialias() const {
