@@ -23,6 +23,7 @@
 #include <QTimer>
 #include <LXQt/SingleApplication>
 #include <QCommandLineParser>
+#include <QMessageBox>
 #include "brightnesssettings.h"
 
 #include <iostream>
@@ -99,7 +100,6 @@ static CommandLineParseResult parseCommandLine(QCommandLineParser *parser, Brigh
 
     const bool isIncreaseSet = parser->isSet(increaseOption);
     const bool isDecreaseSet = parser->isSet(decreaseOption);
-    const QString increase_value = parser->value(increaseOption);
 
     const bool isSetBrightnessSet = parser->isSet(setOption);
     float brightnessValue = 0.0f;
@@ -160,9 +160,9 @@ int main(int argn, char* argv[])
     }
 
     if (config.mode == UiMode::GUI) {
-        BrightnessSettings *brightnessSettings = new BrightnessSettings();
-        brightnessSettings->setWindowIcon(QIcon(QLatin1String(ICON_DIR) + QStringLiteral("/brightnesssettings.svg")));
-        brightnessSettings->show();
+        BrightnessSettings brightnessSettings;
+        brightnessSettings.setWindowIcon(QIcon(QLatin1String(ICON_DIR) + QStringLiteral("/brightnesssettings.svg")));
+        brightnessSettings.show();
         return app.exec();
     }
 
@@ -230,6 +230,7 @@ int main(int argn, char* argv[])
             }
         }
         brightness->setMonitorsSettings(monitorsChanged);
+        delete brightness;
         return 0;
     }
 
